==> v8.3.zip: ru_twords_ru_tw/bible/other/trouble.md <==
# трудность, смущать, беспокоящийся, затруднения, горе

## Определение:

Трудностями называются тяжёлые и причиняющие страдания жизненные переживания. Иногда в этом значении используется слово скорбь. Слово “беспокоить” означает “надоедать кому-либо”, “причинить трудности”, “смущать”. Слово “беспокоиться” означает “испытывать страхи, волнения, опасения” и т.д.

* Затруднениями называются физические, эмоциональные или духовные переживания, беспокоящие человека.
* Когда Господь посылает людям испытания, затруднения, трудности, горе и т.д., Он делает это для того, чтобы помочь верующим стать ещё более зрелыми.

## Варианты перевода:

* Слова “трудность”, “затруднения” можно перевести как “переживания”, “сложные обстоятельства”, “болезненные происшествия”, “тяжёлые условия” и т.д.
* Слово “беспокоящийся” можно перевести как: “испытывающий муки”, “обеспокоенный”, “встревоженный”, “испуганный”.
* Словосочетание “не беспокоить” можно перевести словосочетанием “не надоедать”.
* Выражение “день печали”, “времена скорби” можно перевести как “период мучений”, “тяжёлые испытания”, “сложные времена”.
* Словосочетания “создавать проблемы” или “приносить проблемы” можно перевести как “создавать сложности, трудности, невзгоды” или “заставлять людей переживать трудности”.

(См. также: [притеснять](../other/afflict.md), [преследование](../other/persecute.md))

## Ссылки на библейский текст:

* [3 Цар. 18:18-19](rc://*/tn/help/1ki/18/18)
* [2 Пар. 25:18-19](rc://*/tn/help/2ch/25/18)
* [Лк. 24:38-40](rc://*/tn/help/luk/24/38)
* [Мф. 24:6-8](rc://*/tn/help/mat/24/06)
* [Мф. 26:36-38](rc://*/tn/help/mat/26/36)

## Данные о слове:

* Номера Стронга: H205, H598, H926, H927, H928, H1204, H1205, H1607, H1644, H1804, H1993, H2000, H2113, H2189, H2560, H2960, H4103, H5590, H5753, H5916, H5999, H6031, H6040, H6470, H6696, H6862, H6869, H6887, H7264, H7267, H7451, H7481, H7489, H7515, H7561, H8513, G387, G1298, G1613, G1776, G2346, G2347, G2350, G2360, G2553, G2873, G3636, G3926, G3930, G3986, G4423, G4660, G5015, G5016, G5182

==> v9.2.zip: ru_twords_ru_tw/bible/other/trouble.md <==
# трудность, смущать, беспокоящийся, затруднения, горе

## Определение:

Трудностями называются тяжёлые и причиняющие страдания жизненные переживания. Иногда в этом значении используется слово скорбь. Слово “беспокоить” означает “надоедать кому-либо”, “причинить трудности”, “смущать”. Слово “беспокоиться” означает “испытывать страхи, волнения, опасения” и т.д.
* Затруднениями называются физические, эмоциональные или духовные переживания, беспокоящие человека.
* Когда Господь посылает людям испытания, затруднения, трудности, горе и т.д., Он делает это для того, чтобы помочь верующим стать ещё более зрелыми.

## Варианты перевода:

* Слова “трудность”, “затруднения” можно перевести как “переживания”, “сложные обстоятельства”, “болезненные происшествия”, “тяжёлые условия” и т.д.
* Слово “беспокоящийся” можно перевести как: “испытывающий муки”, “обеспокоенный”, “встревоженный”, “испуганный”.
* Словосочетание “не беспокоить” можно перевести словосочетанием “не надоедать”.
* Выражение “день печали”, “времена скорби” можно перевести как “период мучений”, “тяжёлые испытания”, “сложные времена”.
* Словосочетания “создавать проблемы” или “приносить проблемы” можно перевести как “создавать сложности, трудности, невзгоды” или “заставлять людей переживать трудности”.

(См. также: [притеснять](../other/afflict.md), [преследование](../other/persecute.md))

## Ссылки на библейский текст:

* [3 Цар. 18:18-19](rc://ru/tn/help/1ki/18/18)
* [2 Пар. 25:18-19](rc://ru/tn/help/2ch/25/18)
* [Лк. 24:38-40](rc://ru/tn/help/luk/24/38)
* [Мф. 24:6-8](rc://ru/tn/help/mat/24/06)
* [Мф. 26:36-38](rc://ru/tn/help/mat/26/36)

## Данные о слове:

* Номера Стронга: H205, H598, H926, H927, H928, H1204, H1205, H1607, H1644, H1804, H1993, H2000, H2113, H2189, H2560, H2960, H4103, H5590, H5753, H5916, H5999, H6031, H6040, H6470, H6696, H6862, H6869, H6887, H7264, H7267, H7451, H7481, H7489, H7515, H7561, H8513, G387, G1298, G1613, G1776, G2346, G2347, G2350, G2360, G2553, G2873, G3636, G3926, G3930, G3986, G4423, G4660, G5015, G5016, G5182
